@@ -1,5 +1,7 @@
 var NAVTREEINDEX4 =
 {
+"group__cpp__addons__doc.html#ga6be5f8303fd180a587d67d7f01fb44a1":[17,1,1,3,8],
+"group__cpp__addons__doc.html#ga74f596ae15851fab025e23b536afcccd":[17,1,1,3,11],
 "group__cpp__addons__doc.html#ga86918c97a1d4617dd43f48d4e966641d":[17,1,1,3,9],
 "group__cpp__addons__doc.html#ga8f84eea617a139d8a7a6cc52039d4078":[17,1,1,3,14],
 "group__cpp__addons__doc.html#ga9898033ab60172b2ed5b675b99b96426":[17,1,1,3,17],
@@ -33,36 +35,41 @@ var NAVTREEINDEX4 =
 "group__cpp__addons__json.html#gaf8f9794d1cca94722dbc8af8c2f97679":[17,1,1,5,5],
 "group__cpp__addons__json.html#gafbf781155476437fcf38d37e2380f8a8":[17,1,1,5,8],
 "group__cpp__addons__meta.html":[17,1,1,6],
-"group__cpp__addons__meta.html#ga0b531f451234e48028d84593a4a22a9f":[17,1,1,6,25],
-"group__cpp__addons__meta.html#ga108fe405178ca7e719d70fdea54ff9c7":[17,1,1,6,22],
-"group__cpp__addons__meta.html#ga10cfb986c203ee0cb3e3c7dc4dd58d57":[17,1,1,6,16],
-"group__cpp__addons__meta.html#ga214115faabfcb6fbe39e076ed0d7c17f":[17,1,1,6,18],
+"group__cpp__addons__meta.html#ga0b531f451234e48028d84593a4a22a9f":[17,1,1,6,30],
+"group__cpp__addons__meta.html#ga108fe405178ca7e719d70fdea54ff9c7":[17,1,1,6,27],
+"group__cpp__addons__meta.html#ga13f4322cddb125f676dade62bdc41ed7":[17,1,1,6,17],
+"group__cpp__addons__meta.html#ga1f1110665e3ab71a58f08ac6fcc0430f":[17,1,1,6,18],
+"group__cpp__addons__meta.html#ga22af278fbce063ba13b314ccacfbba10":[17,1,1,6,25],
 "group__cpp__addons__meta.html#ga232842b5b739911a9124334f8e70981c":[17,1,1,6,10],
 "group__cpp__addons__meta.html#ga290dbe18df4d2739f6e3412470f7e421":[17,1,1,6,7],
-"group__cpp__addons__meta.html#ga2bc94f1781c3f53ee9191cf26da588ae":[17,1,1,6,27],
+"group__cpp__addons__meta.html#ga29a5211857f86f17000556ab31ae2afd":[17,1,1,6,19],
+"group__cpp__addons__meta.html#ga2bc94f1781c3f53ee9191cf26da588ae":[17,1,1,6,32],
+"group__cpp__addons__meta.html#ga2c426e74053c6fcda37c20d0a13c2aa1":[17,1,1,6,23],
 "group__cpp__addons__meta.html#ga35bfe812608b4c02dd1058e71834c974":[17,1,1,6,5],
-"group__cpp__addons__meta.html#ga38ba92b2cb86f06542229069b62a3411":[17,1,1,6,20],
-"group__cpp__addons__meta.html#ga4b3d8d87501d602f2911da0f0b473536":[17,1,1,6,24],
+"group__cpp__addons__meta.html#ga38ba92b2cb86f06542229069b62a3411":[17,1,1,6,24],
+"group__cpp__addons__meta.html#ga4b3d8d87501d602f2911da0f0b473536":[17,1,1,6,29],
 "group__cpp__addons__meta.html#ga54a7c8f1b846be215f0fc2d86298603e":[17,1,1,6,8],
-"group__cpp__addons__meta.html#ga57aba8f77bdfb15b7dbcc910d2a74701":[17,1,1,6,32],
-"group__cpp__addons__meta.html#ga5876427fe4e3cd6077cd03819d7758e7":[17,1,1,6,28],
-"group__cpp__addons__meta.html#ga69703aa8f660f9934e8f3c4ee8ee85ed":[17,1,1,6,17],
-"group__cpp__addons__meta.html#ga72b3a9713d33456ff9ee3964f1122ec9":[17,1,1,6,29],
-"group__cpp__addons__meta.html#ga75a9f2aece32230bfcf142248c81208a":[17,1,1,6,31],
+"group__cpp__addons__meta.html#ga57aba8f77bdfb15b7dbcc910d2a74701":[17,1,1,6,37],
+"group__cpp__addons__meta.html#ga5876427fe4e3cd6077cd03819d7758e7":[17,1,1,6,33],
+"group__cpp__addons__meta.html#ga5e43f64d820a27818a9b46514a1e3333":[17,1,1,6,26],
+"group__cpp__addons__meta.html#ga6dcc60d7bcfd820d4e0e6ebc8476818f":[17,1,1,6,22],
+"group__cpp__addons__meta.html#ga72b3a9713d33456ff9ee3964f1122ec9":[17,1,1,6,34],
+"group__cpp__addons__meta.html#ga75a9f2aece32230bfcf142248c81208a":[17,1,1,6,36],
+"group__cpp__addons__meta.html#ga77d00535e0aebd71ccafc92d29883dc6":[17,1,1,6,20],
 "group__cpp__addons__meta.html#ga7801bddc835d400dc71c6261f64fba2b":[17,1,1,6,11],
 "group__cpp__addons__meta.html#ga83a26164619fc68d6c5facd8b6da2671":[17,1,1,6,6],
 "group__cpp__addons__meta.html#ga987426ea7bc2a0aee1850f77c2512888":[17,1,1,6,3],
-"group__cpp__addons__meta.html#gac38baa85a49b23f624cbb8490ed32503":[17,1,1,6,26],
-"group__cpp__addons__meta.html#gac86161629bc421f597655579e8694b04":[17,1,1,6,23],
+"group__cpp__addons__meta.html#gac38baa85a49b23f624cbb8490ed32503":[17,1,1,6,31],
+"group__cpp__addons__meta.html#gac86161629bc421f597655579e8694b04":[17,1,1,6,28],
 "group__cpp__addons__meta.html#gacd2ebeff1d616dd3fe4da8cf655d0ee3":[17,1,1,6,4],
 "group__cpp__addons__meta.html#gad3e2eea6ea2be79ca62b92998b62ce07":[17,1,1,6,14],
-"group__cpp__addons__meta.html#gad6fa0ad6b1280dec47aaa3ae05beda40":[17,1,1,6,30],
+"group__cpp__addons__meta.html#gad6fa0ad6b1280dec47aaa3ae05beda40":[17,1,1,6,35],
+"group__cpp__addons__meta.html#gad8b0f60b189fceeaf1bd435935945975":[17,1,1,6,21],
 "group__cpp__addons__meta.html#gadd5248abcf5015b6e743b226e9ae9097":[17,1,1,6,15],
 "group__cpp__addons__meta.html#gaf0f195a58a7d935aabbf5848aeaaeaf4":[17,1,1,6,9],
 "group__cpp__addons__meta.html#gaf14e2f21de0df9ac42c914b5bf942b8b":[17,1,1,6,12],
+"group__cpp__addons__meta.html#gaf19a7d2a71849b9adf2049083809d950":[17,1,1,6,16],
 "group__cpp__addons__meta.html#gaf49405e273bee2ffa0eebb5b3f2f3644":[17,1,1,6,13],
-"group__cpp__addons__meta.html#gaf539757603e7c75bc52cbc85b0806123":[17,1,1,6,21],
-"group__cpp__addons__meta.html#gafd33eb625175ba8b0c4323e3a2be85a1":[17,1,1,6,19],
 "group__cpp__addons__metrics.html":[17,1,1,7],
 "group__cpp__addons__metrics.html#gae510f6152ca2e1ed8224a679e944986e":[17,1,1,7,2],
 "group__cpp__addons__metrics.html#gaeef24599a6266c5f4e34e681dcd6348f":[17,1,1,7,3],
@@ -242,12 +249,5 @@ var NAVTREEINDEX4 =
 "group__flecs__c__creation.html#ga6d1d4e4fb0236c6c22945b4dcc74b043":[17,0,3,0,18],
 "group__flecs__c__creation.html#ga6e12bc20b1996fd3cb5f1d2610cc6c06":[17,0,3,0,17],
 "group__flecs__c__creation.html#ga74cab14dbe6c391e926af1123aa059e8":[17,0,3,0,16],
-"group__flecs__c__creation.html#ga8354485aaa3554a52832841d16bba1e8":[17,0,3,0,12],
-"group__flecs__c__creation.html#ga84d26a4f0ae7d95bcbffad8c105a12f1":[17,0,3,0,8],
-"group__flecs__c__creation.html#ga863fdad64aedde0d2672f438cead5a37":[17,0,3,0,20],
-"group__flecs__c__creation.html#ga8a51bd4bba46e889a4a2efeae14c4e95":[17,0,3,0,15],
-"group__flecs__c__creation.html#ga98ac9050fbd22876f1acdcec080b4047":[17,0,3,0,11],
-"group__flecs__c__creation.html#ga9d8acf44874778a01d6195a1c8e86c3d":[17,0,3,0,13],
-"group__flecs__c__creation.html#gaa9611eee7fc23785c8ac061951a031e6":[17,0,3,0,1],
-"group__flecs__c__creation.html#gac15ca7a5ac57590b878f0fc6635284f8":[17,0,3,0,2]
+"group__flecs__c__creation.html#ga8354485aaa3554a52832841d16bba1e8":[17,0,3,0,12]
 };
